@@ -1,8 +1,9 @@
-from .config import PATH
+from .config import PATH, PDF_REPORT_JOB_FOLDER
 from .security import get_access_token
 from .process_job import process_job
 from .logging import logger
 import json
+import shutil
 
 
 class PDF_report:
@@ -11,11 +12,23 @@ class PDF_report:
 
     def execute(self, job):
 
+        # Copy <your_job>.json         
+        if not PDF_REPORT_JOB_FOLDER == None:
+            src="{}/{}".format(PDF_REPORT_JOB_FOLDER, job)
+            des="{}jobs/{}".format(PATH, job)
+            shutil.copy(src, des)
+        
         # Open the json file
         file = open("{}jobs/{}".format(PATH, job), "r")
         job_detail = json.load(file)
         file.close()
 
+        #Copy <your_job>.tex
+        if not PDF_REPORT_JOB_FOLDER == None:
+            src="{}/{}".format(PDF_REPORT_JOB_FOLDER, job_detail["filename"])
+            des="{}latex/{}".format(PATH, job_detail["filename"])
+            shutil.copy(src, des)
+
         # Check if selected job is active
         if not job_detail["active"]:
             print("Job {} ist not active".format(job))
